@@ -8,7 +8,6 @@
 # pylint: disable=too-many-public-methods
 # pylint: disable=bad-continuation
 # pylint: disable=bad-indentation
-# pylint: disable=too-many-arguments
 # pylint: disable=len-as-condition
 # pylint: disable=no-self-use
 # pylint: disable=line-too-long
@@ -19,7 +18,7 @@ from decimal import Decimal
 import numpy
 from tzlocal import get_localzone
 
-from okera import version, _thrift_api, context
+from okera import version, _thrift_api
 from okera.tests import pycerebro_test_common as common
 from okera._thrift_api import TAccessPermissionLevel
 
@@ -41,10 +40,11 @@ class BasicTest(unittest.TestCase):
         self.assertTrue(version())
 
     def test_connection(self):
-        planner = common.get_planner()
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
         self.assertEqual("1.0", planner.get_protocol_version())
         planner.close()
-        worker = common.get_worker()
+        worker = common.get_worker(ctx)
         self.assertEqual("1.0", worker.get_protocol_version())
         worker.close()
 
@@ -130,26 +130,27 @@ class BasicTest(unittest.TestCase):
 
     def test_planner(self):
         ctx = common.get_test_context()
-        planner = ctx.connect()
+        planner = common.get_planner(ctx)
         self.assertEqual('1.0', planner.get_protocol_version())
         planner.close()
 
         # Should be able to make more
-        with ctx.connect() as planner:
+        with common.get_planner(ctx) as planner:
             self.assertEqual('1.0', planner.get_protocol_version())
 
     def test_worker(self):
         ctx = common.get_test_context()
-        worker = ctx.connect_worker()
+        worker = common.get_worker(ctx)
         self.assertEqual('1.0', worker.get_protocol_version())
         worker.close()
 
         # Should be able to make more
-        with ctx.connect_worker() as worker:
+        with common.get_worker(ctx) as worker:
             self.assertEqual('1.0', worker.get_protocol_version())
 
     def test_catalog(self):
-        planner = common.get_planner()
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
         dbs = planner.list_databases()
         self.assertTrue('okera_sample' in dbs)
         datasets = planner.list_datasets('okera_sample')
@@ -160,20 +161,23 @@ class BasicTest(unittest.TestCase):
         planner.close()
 
     def test_ddl(self):
-        planner = common.get_planner()
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
         result = planner.execute_ddl("show databases")
         planner.close()
         print(result)
         self.assertTrue(len(result) > 3)
 
     def test_plan(self):
-        planner = common.get_planner()
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
         plan = planner.plan("tpch.nation")
         self.assertEqual(1, len(plan.tasks))
         planner.close()
 
     def test_task_split(self):
-        planner = common.get_planner()
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
         #large file no compression creates splits
         plan = planner.plan("rs.alltypes_large_s3")
         self.assertTrue(len(plan.tasks) > 1)
@@ -192,7 +196,8 @@ class BasicTest(unittest.TestCase):
         planner.close()
 
     def test_all_types_json(self):
-        planner = common.get_planner()
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
         json = planner.scan_as_json("rs.alltypes")
         planner.close()
         self.assertEqual(2, len(json))
@@ -214,7 +219,8 @@ class BasicTest(unittest.TestCase):
         self.assertEqual('2016-01-01 00:00:00.000', str(r2['timestamp_col']))
 
     def test_requesting_user(self):
-        planner = common.get_planner()
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
         json = planner.scan_as_json("rs.alltypes", requesting_user="testuser")
         planner.close()
         self.assertEqual(2, len(json))
@@ -223,13 +229,13 @@ class BasicTest(unittest.TestCase):
         self.assertEqual({'int_col' : 2, 'string_col' : 'hello'}, r1)
         self.assertEqual({'int_col' : 8, 'string_col' : 'world'}, r2)
 
-        planner = common.get_planner()
+        planner = common.get_planner(ctx)
         pd = planner.scan_as_pandas("rs.alltypes", requesting_user="testuser")
         planner.close()
         self.assertEqual(2, len(pd))
         self.assertEqual(['int_col', 'string_col'], list(pd.columns))
 
-        planner = common.get_planner()
+        planner = common.get_planner(ctx)
         ddl = planner.execute_ddl(
             'describe okera_sample.users', requesting_user="testuser")
         self.assertEqual([
@@ -243,13 +249,14 @@ class BasicTest(unittest.TestCase):
             ['uid', 'string', 'Unique user id', ''],
         ], sorted(ddl, key=lambda item: item[0]))
 
-        planner = common.get_planner()
+        planner = common.get_planner(ctx)
         with self.assertRaises(_thrift_api.TRecordServiceException):
             planner.execute_ddl(
                 'describe okera_system.attributes', requesting_user="testuser")
 
     def test_all_types_pandas(self):
-        planner = common.get_planner()
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
         pd = planner.scan_as_pandas("rs.alltypes")
         planner.close()
         self.assertEqual(2, len(pd))
@@ -281,7 +288,8 @@ class BasicTest(unittest.TestCase):
         self.assertEqual('2016-01-01 00:00:00+00:00', str(pd['timestamp_col'][1]))
 
     def test_all_types_null_pandas(self):
-        planner = common.get_planner()
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
         pd = planner.scan_as_pandas("rs.alltypes_null")
         planner.close()
         self.assertEqual(1, len(pd))
@@ -290,7 +298,8 @@ class BasicTest(unittest.TestCase):
             self.assertTrue(numpy.isnan(pd.iloc[0, i]), msg=pd)
 
     def test_all_types_empty(self):
-        planner = common.get_planner()
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
         pd = planner.scan_as_pandas("rs.alltypes_empty")
         planner.close()
         self.assertEqual(
@@ -302,7 +311,8 @@ class BasicTest(unittest.TestCase):
         self.assertEqual(12, len(pd.columns), msg=pd)
 
     def test_all_types_null_json(self):
-        planner = common.get_planner()
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
         json = planner.scan_as_json("rs.alltypes_null")
         planner.close()
         self.assertEqual(1, len(json), msg=json)
@@ -311,13 +321,15 @@ class BasicTest(unittest.TestCase):
             self.assertTrue(json[0][v] is None, msg=json[0])
 
     def test_all_types_empty_json(self):
-        planner = common.get_planner()
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
         json = planner.scan_as_json("rs.alltypes_empty")
         planner.close()
         self.assertEqual(0, len(json), msg=json)
 
     def test_filter_with_empty_rows_pandas(self):
-        planner = common.get_planner()
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
         pd = planner.scan_as_pandas(
             "SELECT * FROM okera_sample.users where gender = 'lol'"
         )
@@ -325,7 +337,8 @@ class BasicTest(unittest.TestCase):
         self.assertEqual(0, len(pd), msg=pd)
 
     def test_column_order_scan_as_pandas(self):
-        planner = common.get_planner()
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
         self.assertEqual(
             list(planner.scan_as_pandas("okera_sample.users").columns),
             ['uid', 'dob', 'gender', 'ccn'])
@@ -344,7 +357,8 @@ class BasicTest(unittest.TestCase):
             ['decimal_col', 'bigint_col'])
 
     def test_binary_data(self):
-        with common.get_planner() as planner:
+        ctx = common.get_test_context()
+        with common.get_planner(ctx) as planner:
             planner.execute_ddl("create database if not exists binarydb")
             planner.execute_ddl("""
                 create external table if not exists binarydb.sample (record binary)
@@ -360,7 +374,8 @@ class BasicTest(unittest.TestCase):
             planner.execute_ddl("drop database binarydb")
 
     def test_warnings(self):
-        with common.get_planner() as planner:
+        ctx = common.get_test_context()
+        with common.get_planner(ctx) as planner:
             warnings = []
             result = planner.scan_as_json("okera_sample.sample", warnings=warnings)
             self.assertEqual(2, len(result))
@@ -374,7 +389,7 @@ class BasicTest(unittest.TestCase):
     def test_impersonation(self):
         ctx = common.get_test_context()
         ctx.enable_token_auth('testuser')
-        with ctx.connect() as planner:
+        with common.get_planner(ctx) as planner:
             # Spot check a few
             dbs = []
             for r in planner.execute_ddl('show databases'):
@@ -403,7 +418,7 @@ class BasicTest(unittest.TestCase):
 
     def test_get_objects_at_path(self):
         ctx = common.get_test_context()
-        with ctx.connect() as planner:
+        with common.get_planner(ctx) as planner:
             planner.execute_ddl("drop database if exists getobjectsdb cascade")
             planner.execute_ddl("create database if not exists getobjectsdb")
             planner.execute_ddl("""
@@ -453,7 +468,7 @@ class BasicTest(unittest.TestCase):
 
     def test_decimal_serialization_json(self):
       ctx = common.get_test_context()
-      with ctx.connect() as p:
+      with common.get_planner(ctx) as p:
         self.verify_decimal_value_json(p, '100.12', 38, 2)
         self.verify_decimal_value_json(p, '-200.34', 38, 2)
         self.verify_decimal_value_json(p, '-300.56', 38, 2)
@@ -489,7 +504,7 @@ class BasicTest(unittest.TestCase):
 
     def test_decimal_serialization_pandas(self):
       ctx = common.get_test_context()
-      with ctx.connect() as p:
+      with common.get_planner(ctx) as p:
         self.verify_decimal_value_pandas(p, '100.12', 38, 2)
         self.verify_decimal_value_pandas(p, '-200.34', 38, 2)
         self.verify_decimal_value_pandas(p, '-300.56', 38, 2)
@@ -507,7 +522,8 @@ class BasicTest(unittest.TestCase):
                                        0, Decimal('-1.701411834604692317316873037E+37'))
 
     def test_create_from_show_create_table(self):
-        with common.get_planner() as planner:
+        ctx = common.get_test_context()
+        with common.get_planner(ctx) as planner:
             ## Test by modifying output of show create, by replacing table name,
             ## create the new table, and delete the same after verification
 
@@ -566,7 +582,6 @@ class BasicTest(unittest.TestCase):
             planner.execute_ddl(drop_table_ddl)
 
     def test_get_datasets_databases_with_privilege(self):
-        ctx = context()
         ATTR = ['priv_filter_test', 'attr1']
         DB1 = 'test_access_db1'
         DB2 = 'test_access_db2'
@@ -576,7 +591,8 @@ class BasicTest(unittest.TestCase):
         TBL2 = 'tbl2'
         ROLE = 'test_access_level_role'
         USER = 'test_access_level_user'
-        with ctx.connect(host='localhost', port=12050) as conn:
+        ctx = common.get_test_context()
+        with common.get_planner(ctx) as conn:
             for db in [DB1, DB2, DB3, DB4]:
                 conn.execute_ddl('DROP DATABASE IF EXISTS %s CASCADE' % db)
                 conn.execute_ddl('CREATE DATABASE %s' % db)
@@ -662,8 +678,8 @@ class BasicTest(unittest.TestCase):
             assert DB4 not in dbs
 
     def test_get_datasets_with_low_privs(self):
-        ctx = context()
-        with ctx.connect(host='localhost', port=12050) as conn:
+        ctx = common.get_test_context()
+        with common.get_planner(ctx) as conn:
 
             def sensitive_data_check(dataset, is_view, should_exist):
                 if not is_view:
@@ -715,7 +731,7 @@ class BasicTest(unittest.TestCase):
 
     def test_no_sandbox(self):
       ctx = common.get_test_context()
-      with ctx.connect() as conn:
+      with common.get_planner(ctx) as conn:
         dbs = conn.list_databases()
         assert 'okera_sandbox' not in dbs
 
