@@ -2,7 +2,6 @@
 #
 # Some integration tests for role granting
 #
-# pylint: disable=too-many-arguments
 # pylint: disable=too-many-public-methods
 # pylint: disable=line-too-long
 # pylint: disable=len-as-condition
@@ -10,7 +9,8 @@
 
 import unittest
 
-from okera import context
+from okera._thrift_api import TAuthorizeQueryParams
+from okera.tests import pycerebro_test_common as common
 
 DB = 'test_privacy_db'
 ROLE = 'test_privacy_role'
@@ -208,6 +208,13 @@ def scan_as_json(ctx, conn, query, dialect='okera', user=None):
         ctx.disable_auth()
     return res
 
+def authorize_query(conn, query, user):
+    request = TAuthorizeQueryParams()
+    request.sql = query
+    request.requesting_user = user
+    result = conn.service.client.AuthorizeQuery(request)
+    return ' '.join(result.result_sql.split())
+
 class PrivacyTest(unittest.TestCase):
     def _validate_query(self, ctx, conn, query,
                         equal_across_users=True, equal_across_queries=True,
@@ -257,8 +264,8 @@ class PrivacyTest(unittest.TestCase):
 
     def _test_fn(self, fn, maintains_ref_integrity, stable, maintains_type):
         PRIVACY_FN = fn
-        ctx = context()
-        with ctx.connect() as conn:
+        ctx = common.get_test_context()
+        with common.get_planner(ctx) as conn:
             conn.execute_ddl('DROP ATTRIBUTE IF EXISTS %s' % ATTR1)
             conn.execute_ddl('DROP ATTRIBUTE IF EXISTS %s' % ATTR2)
             conn.execute_ddl('DROP ROLE IF EXISTS %s' % ROLE)
@@ -309,6 +316,21 @@ class PrivacyTest(unittest.TestCase):
                                'SELECT * FROM %s.%s' % (DB, ALLTYPES_TABLE))
             self.assertTrue(res == ALLTYPES_RESULTS)
 
+            # Verify that for authorize query, no seed is added to the privacy
+            # function.
+            authorized_sql = authorize_query(
+                conn, 'SELECT * FROM %s.%s' % (DB, ALLTYPES_TABLE), USER1)
+            expected = ("SELECT %s(bool_col) as bool_col, " +
+                        "%s(tinyint_col) as tinyint_col, " +
+                        "%s(smallint_col) as smallint_col, " +
+                        "%s(int_col) as int_col, " +
+                        "%s(bigint_col) as bigint_col, " +
+                        "float_col, double_col, string_col, varchar_col, " +
+                        "char_col, timestamp_col, decimal_col " +
+                        "FROM test_privacy_db.alltypes") %\
+                         (fn, fn, fn, fn, fn)
+            self.assertEqual(authorized_sql, expected)
+
             # When executed against a table with a grant, should see the same thing
             # by default
             self._validate_query(ctx, conn,
@@ -451,30 +473,36 @@ class PrivacyTest(unittest.TestCase):
                     self._validate_query(ctx, conn, join_query,
                                          equal_across_queries=False, equal_across_users=False, has_results=False)
 
+    @unittest.skipIf(common.test_level_lt('checkin'), "Skipping below checkin test level")
     def test_nfp_ref_tokenize(self):
         self._test_fn('nfp_ref_tokenize', maintains_ref_integrity=True, stable=True, maintains_type=False)
 
     def test_nfp_noref_tokenize(self):
         self._test_fn('nfp_noref_tokenize', maintains_ref_integrity=False, stable=True, maintains_type=False)
 
+    @unittest.skipIf(common.test_level_lt('checkin'), "Skipping below checkin test level")
     def test_fp_ref_tokenize(self):
         self._test_fn('fp_ref_tokenize', maintains_ref_integrity=True, stable=True, maintains_type=True)
 
     def test_fp_noref_tokenize(self):
         self._test_fn('fp_noref_tokenize', maintains_ref_integrity=False, stable=True, maintains_type=True)
 
+    @unittest.skipIf(common.test_level_lt('checkin'), "Skipping below checkin test level")
     def test_fpt(self):
         self._test_fn('fpt', maintains_ref_integrity=False, stable=True, maintains_type=True)
 
     def test_fpt_ref(self):
         self._test_fn('fpt_ref', maintains_ref_integrity=True, stable=True, maintains_type=True)
 
+    @unittest.skipIf(common.test_level_lt('checkin'), "Skipping below checkin test level")
     def test_tokenize_no_ref(self):
         self._test_fn('tokenize_no_ref', maintains_ref_integrity=False, stable=True, maintains_type=True)
 
+    @unittest.skipIf(common.test_level_lt('checkin'), "Skipping below checkin test level")
     def test_tokenize(self):
         self._test_fn('tokenize', maintains_ref_integrity=True, stable=True, maintains_type=True)
 
+    @unittest.skipIf(common.test_level_lt('checkin'), "Skipping below checkin test level")
     def test_fp_random(self):
         self._test_fn('fp_random', maintains_ref_integrity=False, stable=False, maintains_type=True)
 
